﻿using System.Windows;
using ThinkGeo.MapSuite;
using ThinkGeo.MapSuite.Layers;
using ThinkGeo.MapSuite.Styles;
using ThinkGeo.MapSuite.Wpf;
using ThinkGeo.MapSuite.Shapes;

namespace _8637
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        string bingMapsKey = "Your Bing Key";
        PointShape targetPoint = new PointShape(-86.24620, 36.77823);

        public MainWindow()
        {
            InitializeComponent();
        }

        private void map_Loaded(object sender, RoutedEventArgs e)
        {
            map.MapUnit = GeographyUnit.Meter;
            map.ZoomLevelSet = new BingMapsZoomLevelSet();

            LayerOverlay layerOverlay = new LayerOverlay();
            BingMapsLayer bingLayer = new BingMapsLayer(bingMapsKey, ThinkGeo.MapSuite.Layers.BingMapsMapType.Aerial);
            bingLayer.SendingWebRequest += BingLayer_SendingWebRequest;

            layerOverlay.Layers.Add(bingLayer);
            map.Overlays.Add(layerOverlay);
                        
            Proj4Projection proj4 = new Proj4Projection();
            proj4.InternalProjectionParametersString = Proj4Projection.GetDecimalDegreesParametersString();
            proj4.ExternalProjectionParametersString = Proj4Projection.GetBingMapParametersString();
            proj4.Open();

            map.CurrentScale = new BingMapsZoomLevelSet().ZoomLevel18.Scale;
            map.CenterAt(proj4.ConvertToExternalProjection(targetPoint) as PointShape);
            
            map.Refresh();
        }

        private void BingLayer_SendingWebRequest(object sender, SendingWebRequestEventArgs e)
        {
            System.Diagnostics.Debug.WriteLine(e.WebRequest.RequestUri.ToString());
        }
    }
}
